# Generated by Django 2.0.2 on 2018-05-07 13:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0002_auto_20180414_2144'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='argument',
            unique_together={('character', 'chat_type')},
        ),
    ]
