# Generated by Django 2.0.4 on 2018-11-01 20:45

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0005_auto_20181015_2207'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customcontenttemplate',
            name='attachment_template',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, help_text="A JSON object added to a message's attachments whose         values may be Python formatted strings. The args given to formatted         strings are the capture groups matched by the search string.", null=True),
        ),
        migrations.AlterField(
            model_name='customcontenttemplate',
            name='kwarg_template',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, help_text="A JSON object added to a message's kwargs whose values may         be Python formatted strings. The args given to formatted strings are         the capture groups matched by the search string.", null=True),
        ),
    ]
