# Generated by Django 2.0.4 on 2018-10-15 20:32

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0003_auto_20180507_1315'),
    ]

    operations = [
        migrations.AddField(
            model_name='customcontenttemplate',
            name='argument_template',
            field=models.TextField(blank=True, help_text='A Python format string whose args are the capture groups         matched by the search_string.', null=True),
        ),
        migrations.AddField(
            model_name='customcontenttemplate',
            name='attachment_template',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, help_text="A JSON object with Python formatted strings whose args are         the capture groups matched by the search_string and added to the         message's attachments.", null=True),
        ),
        migrations.AddField(
            model_name='customcontenttemplate',
            name='kwarg_template',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, help_text="A JSON object with Python formatted strings whose args are         the capture groups matched by the search_string and added to the         message's kwargs (overridden by manual kwargs in the thread).", null=True),
        ),
        migrations.AlterField(
            model_name='customcontenttemplate',
            name='content_template',
            field=models.TextField(blank=True, help_text='A Python format string whose args are the capture groups         matched by the search_string.', null=True),
        ),
    ]
