# Generated by Django 2.0.4 on 2018-10-15 22:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0004_auto_20181015_2032'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='customcontenttemplate',
            name='argument_name',
        ),
        migrations.AlterField(
            model_name='customcontenttemplate',
            name='argument_template',
            field=models.CharField(blank=True, help_text='A comma seprated list of Python format string whose         args are the capture groups matched by the search_string.', max_length=255, null=True),
        ),
    ]
